﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace RuEn
{
    /// <summary>
    /// Attribute class for Collection Duplicate Rules. Check for duplication in an collection
    /// </summary>
    [AttributeUsage(AttributeTargets.Property, Inherited = false, AllowMultiple = true)]
    public class ObjectCollectionRule: CollectionRuleBase
    {
        private string _errorMessage = "Duplicate Items found";        

        /// <summary>
        /// Default Constructoe
        /// </summary>
        public ObjectCollectionRule()
        {
        }

        /// <summary>
        /// Overloaded Constructor
        /// </summary>
        /// <param name="ErrorMessage">Custom Error message from the User</param>
        public ObjectCollectionRule(string ErrorMessage)
        {
            _errorMessage = ErrorMessage;
        }

        /// <summary>
        /// Public property to assign custom error message
        /// </summary>
        public string ErrorMessage
        {
            get { return _errorMessage; }
            set { _errorMessage = value; }
        }

        /// <summary>
        /// Validate the Object Collection to check for duplicate
        /// </summary>
        /// <param name="value">object collection</param>
        /// <param name="ErrorMessage">Error Message</param>
        /// <returns></returns>
        public bool Validate(IList value, string ErrorMessage)
        {
            bool state = true;
            IList tempCol = new ArrayList();
            if (value != null)
            {
                foreach (object s in value)
                {
                    if (tempCol.Contains(s))
                    {
                        state = false;
                        break;
                    }
                    else
                    {
                        tempCol.Add(s);
                    }
                }    
            }
            return state;
        }
    }
}
